==> qtjambi-test-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiTest/QAbstractItemModelTester_shell.h <==
#ifndef QABSTRACTITEMMODELTESTER_SHELL_H
#define QABSTRACTITEMMODELTESTER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qttestlib-config.h>
#if QT_CONFIG(itemmodeltester)
#include <QtTest/qabstractitemmodeltester.h>
#endif //QT_CONFIG(itemmodeltester)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(itemmodeltester)

class QAbstractItemModelTester_shell : public QAbstractItemModelTester, public QtJambiShellInterface
{
public:
    QAbstractItemModelTester_shell(QAbstractItemModel* model0, QAbstractItemModelTester::FailureReportingMode mode1, QObject* parent2 = nullptr);
    QAbstractItemModelTester_shell(QAbstractItemModel* model0, QObject* parent1 = nullptr);
    ~QAbstractItemModelTester_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractItemModelTester_access : public QAbstractItemModelTester
{
};

#endif // QT_CONFIG(itemmodeltester)
#endif // QABSTRACTITEMMODELTESTER_SHELL_H

==> qtjambi-test-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiTest/QAbstractItemModelTester_shell.h <==
#ifndef QABSTRACTITEMMODELTESTER_SHELL_H
#define QABSTRACTITEMMODELTESTER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qttestlib-config.h>
#if QT_CONFIG(itemmodeltester)
#include <QtTest/qabstractitemmodeltester.h>
#endif //QT_CONFIG(itemmodeltester)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(itemmodeltester)

class QAbstractItemModelTester_shell : public QAbstractItemModelTester, public QtJambiShellInterface
{
public:
    QAbstractItemModelTester_shell(QAbstractItemModel* model0, QAbstractItemModelTester::FailureReportingMode mode1, QObject* parent2 = nullptr);
    QAbstractItemModelTester_shell(QAbstractItemModel* model0, QObject* parent1 = nullptr);
    ~QAbstractItemModelTester_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractItemModelTester_access : public QAbstractItemModelTester
{
};

#endif // QT_CONFIG(itemmodeltester)
#endif // QABSTRACTITEMMODELTESTER_SHELL_H
